@@ -1,8 +1,8 @@
-/* $Id: upnppinhole.c,v 1.16 2023/01/28 16:04:01 nanard Exp $ */
+/* $Id: upnppinhole.c,v 1.18 2025/03/22 22:05:19 nanard Exp $ */
 /* vim: tabstop=4 shiftwidth=4 noexpandtab
  * MiniUPnP project
  * http://miniupnp.free.fr/ or https://miniupnp.tuxfamily.org/
- * (c) 2006-2023 Thomas Bernard
+ * (c) 2006-2025 Thomas Bernard
  * This software is subject to the conditions detailed
  * in the LICENCE file provided within the distribution */
 
@@ -159,6 +159,12 @@ lease_file6_add(const char * rem_client,
 	if (timestamp != 0) {
 		timestamp -= upnp_time();
 	}
+	if (rem_client == NULL) {
+		rem_client = "";
+	}
+	if (desc == NULL) {
+		desc = "";
+	}
 
 	fprintf(fd, "%s;%s;%hu;%s;%hu;%u;%u;%s\n",
 	        proto_itoa(proto), int_client, int_port, rem_client, rem_port,
@@ -372,7 +378,7 @@ lease_file6_remove(const char * int_client, unsigned short int_port, int proto,
 
 }
 
-int lease_file6_expire()
+int lease_file6_expire(void)
 {
 	FILE* fd, *fdt;
 	char * p, * p2;
@@ -490,7 +496,7 @@ int lease_file6_expire()
 /* reload_from_lease_file()
  * read lease_file and add the rules contained
  */
-int reload_from_lease_file6()
+int reload_from_lease_file6(void)
 {
 	FILE * fd;
 	char * p, * p2;
