@@ -1,8 +1,8 @@
-/* $Id: upnpredirect.c,v 1.99 2022/10/21 19:44:59 nanard Exp $ */
+/* $Id: upnpredirect.c,v 1.101 2025/03/22 22:19:33 nanard Exp $ */
 /* vim: tabstop=4 shiftwidth=4 noexpandtab
  * MiniUPnP project
  * http://miniupnp.free.fr/ or https://miniupnp.tuxfamily.org/
- * (c) 2006-2022 Thomas Bernard
+ * (c) 2006-2025 Thomas Bernard
  * This software is subject to the conditions detailed
  * in the LICENCE file provided within the distribution */
 
@@ -186,7 +186,7 @@ lease_file_remove(unsigned short eport, int proto)
 /* reload_from_lease_file()
  * read lease_file and add the rules contained
  */
-int reload_from_lease_file()
+int reload_from_lease_file(void)
 {
 	FILE * fd;
 	char * p;
@@ -201,7 +201,7 @@ int reload_from_lease_file()
 #ifndef LEASEFILE_USE_REMAINING_TIME
 	time_t current_unix_time;
 #endif
-	char line[128];
+	char line[320];
 	int r;
 
 	if(!lease_file) return -1;
@@ -270,7 +270,8 @@ int reload_from_lease_file()
 			timestamp += current_time;	/* convert to our time */
 #else
 			if(timestamp <= (unsigned int)current_unix_time) {
-				syslog(LOG_NOTICE, "already expired lease in lease file");
+				syslog(LOG_NOTICE, "already expired lease in lease file (%hu=>%s:%hu %s)",
+				       eport, iaddr, iport, proto);
 				continue;
 			} else {
 				leaseduration = timestamp - current_unix_time;
@@ -581,7 +582,7 @@ upnp_delete_redirection(unsigned short eport, const char * protocol)
 
 /* upnp_get_portmapping_number_of_entries() */
 int
-upnp_get_portmapping_number_of_entries()
+upnp_get_portmapping_number_of_entries(void)
 {
 #if defined(USE_PF) || defined(USE_NFTABLES)
 	return get_redirect_rule_count(ext_if_name);
